Macros
- Enter an element into the plugin registry corresponding to its type.
Structs
- lazy autowired
Traits
Functions
- return true if component exists
- get list of submitted bean name
- add component into a global map return false if component has already existed
- add component into a global map return false if component has already existed or
constructorreturnNone - register component which derives
Bean